let folderPath = 'images/'; // Default path to your images folder
let totalFrames = 10; // Default total number of frames
let fileExtension = 'jpg'; // Default file extension
let frameRate = 24; // Default frame rate (frames per second)
let currentIndex = 1;
let animationContainer;
let playInterval;
let playing = true;
let animationPaused = false; // Variable to track whether the animation is paused
let previousButtonClicked = false;

// Set initial text of playPauseButton
document.getElementById('playPauseButton').textContent = 'Pause';
previousButton.style.display = 'none';
nextButton.style.display = 'none';

// Function to check if an image exists at the given path
function imageExists(path) {
    return new Promise(resolve => {
        const image = new Image();
        image.onload = () => resolve(true);
        image.onerror = () => resolve(false);
        image.src = path;
    });
}

// Function to check if an image exists
async function imageExists(imagePath) {
    return new Promise(resolve => {
        const image = new Image();
        image.onload = () => resolve(true); // Image loaded successfully
        image.onerror = () => resolve(false); // Image failed to load
        image.src = imagePath;
    });
}

// Function to load and display images sequentially
async function loadAndDisplayImage() {
    let imagePath;
    let imageFound = false;

    while (!imageFound && currentIndex <= totalFrames) {
        const imageNumber = currentIndex.toString().padStart(4, '0'); // Pad currentIndex with zeros
        imagePath = `${folderPath}${imageNumber}.${fileExtension}`;

        
        if (await imageExists(imagePath)) {
            imageFound = true;
        } else {
            currentIndex++;
        }
    }

    if (imageFound) {
        const image = new Image();
        image.src = imagePath;
        animationContainer.innerHTML = ''; // Clear the container
        animationContainer.appendChild(image);
        // Display the name of the currently shown image
        document.getElementById('image-name').textContent = `Current Image: ${imagePath}`;
    }
}

// Function to initialize the animation
function initializeAnimation() {
    animationContainer = document.getElementById('animation-container');
    loadAndDisplayImage(); // Display the first image
    playInterval = setInterval(() => {
        loadAndDisplayImage();
        currentIndex++;
        if (currentIndex > totalFrames) {
            currentIndex = 1; // Loop back to the beginning
        }
    }, 1000 / frameRate); // Start animation loop
}

// Function to update animation parameters
function updateAnimation() {
    folderPath = document.getElementById('folderPathInput').value;
    totalFrames = parseInt(document.getElementById('totalFramesInput').value, 10);
    fileExtension = document.getElementById('fileExtensionSelect').value;
    frameRate = parseInt(document.getElementById('frameRateInput').value, 10);
    currentIndex = 1; // Reset index to start from the beginning
	previousButtonClicked = false;
    clearInterval(playInterval); // Stop current animation loop
    if (playing) {
        playInterval = setInterval(() => {
            loadAndDisplayImage();
            currentIndex++;
            if (currentIndex > totalFrames) {
                currentIndex = 1; // Loop back to the beginning
            }
        }, 1000 / frameRate); // Start new animation loop
    }
    loadAndDisplayImage(); // Display the first image with new parameters
    toggleControlButtons(); // Update control buttons visibility
}

// Function to toggle play/pause
function togglePlayPause() {
    playing = !playing;
    const playPauseButton = document.getElementById('playPauseButton');
    if (playing) {
	animationPaused = false; // Set animationPaused to false
        playPauseButton.textContent = 'Pause';
        playInterval = setInterval(() => {
            loadAndDisplayImage();
            currentIndex++;
            if (currentIndex > totalFrames) {
                currentIndex = 1; // Loop back to the beginning
            }
        }, 1000 / frameRate); // Start animation loop
    } else {
        playPauseButton.textContent = 'Play';
        clearInterval(playInterval); // Pause animation loop
	animationPaused = true; // Set animationPaused to true
    }
    toggleControlButtons(); // Update control buttons visibility
}

// Function to toggle visibility of control buttons based on animation state
function toggleControlButtons() {
    const previousButton = document.getElementById('previousButton');
    const nextButton = document.getElementById('nextButton');
    if (previousButton && nextButton) { // Check if buttons exist
        if (animationPaused) {
            previousButton.style.display = 'inline-block';
            nextButton.style.display = 'inline-block';
        } else {
            previousButton.style.display = 'none';
            nextButton.style.display = 'none';
        }
    }
}

// Function to skip frames
function skipFrame(step) {
    currentIndex += step;
    if (currentIndex > totalFrames) {
        currentIndex = 1; // Loop to the beginning
    } else if (currentIndex < 1) {
        currentIndex = totalFrames; // Loop to the end
    }
    loadAndDisplayImage(); // Load and display the new image
}


// Start animation when the DOM content is loaded
document.addEventListener('DOMContentLoaded', initializeAnimation);

// Add event listener for the "Previous" button
document.getElementById('previousButton').addEventListener('click', function() {
    // Handle click event
    if (!previousButtonClicked) {
        // If Previous button has not been clicked before, set flag to true
        previousButtonClicked = true;
	currentIndex--;
        if (currentIndex < 1) {
            currentIndex = totalFrames; // Loop to the end if currentIndex goes below 1
		} 
	loadAndDisplayImage(); // Load and display the new image
        }
});